@@ -50,7 +50,9 @@ a.B()
 a['x'].C()
 int.x
 map.x
+SELECT call.x
 a.b.INT(1.234)
+INT(x / 100)
 x IN (-1, 1)
 x IN ('a', 'a''a')
 x IN ((1))
@@ -147,6 +149,7 @@ SELECT 1 AS count FROM test
 SELECT 1 AS comment FROM test
 SELECT 1 AS numeric FROM test
 SELECT 1 AS number FROM test
+SELECT 1 AS number # annotation
 SELECT t.count
 SELECT DISTINCT x FROM test
 SELECT DISTINCT x, y FROM test
@@ -159,6 +162,8 @@ SELECT TIMESTAMP(DATE_TRUNC(DATE(time_field), MONTH)) AS time_value FROM "table"
 SELECT GREATEST((3 + 1), LEAST(3, 4))
 SELECT TRANSFORM(a, b -> b) AS x
 SELECT AGGREGATE(a, (a, b) -> a + b) AS x
+SELECT COUNT(DISTINCT a, b)
+SELECT COUNT(DISTINCT a, b + 1)
 SELECT SUM(DISTINCT x)
 SELECT SUM(x IGNORE NULLS) AS x
 SELECT ARRAY_AGG(DISTINCT x IGNORE NULLS ORDER BY a, b DESC LIMIT 10) AS x
@@ -485,6 +490,9 @@ CREATE INDEX abc ON t (a)
 CREATE INDEX abc ON t (a, b, b)
 CREATE UNIQUE INDEX abc ON t (a, b, b)
 CREATE UNIQUE INDEX IF NOT EXISTS my_idx ON tbl (a, b)
+CREATE SCHEMA x
+CREATE SCHEMA IF NOT EXISTS y
+DESCRIBE x
 DROP INDEX a.b.c
 CACHE TABLE x
 CACHE LAZY TABLE x
@@ -524,6 +532,15 @@ INSERT INTO x VALUES (1, 'a', 2.0), (1, 'a', 3.0), (X(), y[1], z.x)
 INSERT INTO y (a, b, c) SELECT a, b, c FROM x
 INSERT OVERWRITE TABLE x IF EXISTS SELECT * FROM y
 INSERT OVERWRITE TABLE a.b IF EXISTS SELECT * FROM y
+INSERT OVERWRITE DIRECTORY 'x' SELECT 1
+INSERT OVERWRITE LOCAL DIRECTORY 'x' SELECT 1
+INSERT OVERWRITE LOCAL DIRECTORY 'x' ROW FORMAT DELIMITED FIELDS TERMINATED BY '1' COLLECTION ITEMS TERMINATED BY '2' MAP KEYS TERMINATED BY '3' LINES TERMINATED BY '4' NULL DEFINED AS '5' SELECT 1
+LOAD DATA INPATH 'x' INTO TABLE y PARTITION(ds='yyyy')
+LOAD DATA LOCAL INPATH 'x' INTO TABLE y PARTITION(ds='yyyy')
+LOAD DATA LOCAL INPATH 'x' INTO TABLE y PARTITION(ds='yyyy') INPUTFORMAT 'y'
+LOAD DATA LOCAL INPATH 'x' INTO TABLE y PARTITION(ds='yyyy') INPUTFORMAT 'y' SERDE 'z'
+LOAD DATA INPATH 'x' INTO TABLE y INPUTFORMAT 'y' SERDE 'z'
+LOAD DATA INPATH 'x' INTO TABLE y.b INPUTFORMAT 'y' SERDE 'z'
 SELECT 1 FROM PARQUET_SCAN('/x/y/*') AS y
 UNCACHE TABLE x
 UNCACHE TABLE IF EXISTS x
