@@ -191,6 +191,20 @@ class TestOptimizer(unittest.TestCase):
             optimizer.optimize_joins.optimize_joins,
         )
 
+    def test_eliminate_joins(self):
+        self.check_file(
+            "eliminate_joins",
+            optimizer.eliminate_joins.eliminate_joins,
+            pretty=True,
+        )
+
+    def test_eliminate_ctes(self):
+        self.check_file(
+            "eliminate_ctes",
+            optimizer.eliminate_ctes.eliminate_ctes,
+            pretty=True,
+        )
+
     def test_merge_subqueries(self):
         optimize = partial(
             optimizer.optimize,
